"complete", read complete librarary tags and sequences;
"tags", read only tags and counts
Details
SAGE library objects consists of one or two data.frames. The
data.frame "tags" contains all the unique tags in the library and its
counts. The data.frame "seqs" contains all the individual tag
sequences and associated quality values. read.sage.library and
write.sage.library are utility functions to read and write SAGE
libraries.