extract.lib.from.zip(zipfile, libname=sub(".zip","",basename(zipfile)), ...)
extract.lib.from.directory(dirname, libname=basename(dirname), pattern, ...)
extract.library.tags(filelist, base.caller.format="phd", remove.duplicate.ditags=TRUE, remove.N=FALSE, remove.low.quality=10, taglength=10, min.ditag.length=(2*taglength-2), max.ditag.length=(2*taglength+4), cut.site="catg", default.quality=NA, verbose=TRUE, ...)
reestimate.lib.from.tagcounts(tagcounts, libname, default.quality=20, ...)
compute.unique.tags(lib)
combine.libs(..., artifacts=c("Linker", "Ribosomal", "Mitochondrial"))
remove.sage.artifacts(lib, artifacts=c("Linker","Ribosomal","Mitochondrial"), ...)
read.phd.file(file)
read.seq.qual.filepair(file, default.quality=NA)
extract.ditags(sequence, taglength=10, filename=NA, min.ditag.length=(2*taglength-2), max.ditag.length=(2*taglength+4), cut.site="catg")libname a character string to be assigned as
library namebase.caller.format can be "phd" or
"seq" or a character vector of the length of the filelistremove.low.quality. Skipped if < 0lib returns an SAGE library object.
extract.lib.from.zip or
extract.lib.from.directory should be used to extract the SAGE
TAGS from the sequences of a library, the sequences need to be
provided by the output files from the base caller software either
in a ZIP archive or in a directory. These are usually the only functions
that should directly be called by the user. The other functions are
called by these and should only be used directly by experienced users
to get more direct control over the process. Most arguments are
passed on and can be specified in the high level
functions. Zipfilenames must be specified using relative pathnames!
sage.library,
error.correction#library(sagenhaft)
#file.copy(system.file("extdata", "E15postHFI.zip",package="sagenhaft"),
# "E15postHFI.zip")
#E15post<-extract.lib.from.zip("E15postHFI.zip", taglength=10,
# min.ditag.length=20, max.ditag.length=24)
#E15post
Run the code above in your browser using DataLab